# Shift Left Secure

## Usage

- add key to environment variable

    ```bash
    export OPEN_API_KEY=KEY
    ```

- Start analyzing changes between commits using below cmd:

    ```bash
    python -m shift_left_secure -d 'path_to_git_project'
    ```
